@@ -60,3 +60,12 @@ class StackLayer(nn.Module):
 
     def forward(self, *elements):
         return torch.stack(tensors=elements, dim=self.dim)
+
+
+class ReshapeLayer(nn.Module):
+    def __init__(self, shape):
+        super().__init__()
+        self.shape = shape
+
+    def forward(self, input):
+        return torch.reshape(input=input, shape=self.shape)
